Package: LWFBrook90R
Title: Simulate Evapotranspiration and Soil Moisture with the SVAT
        Model LWF-Brook90
Version: 0.6.3
Authors@R: c(person("Paul", "Schmidt-Walter", , "paulsw@posteo.de", role = c("aut", "cre"),comment=c(ORCID="0000-0003-2699-0893")),
             person("Volodymyr", "Trotsiuk", , ,role = c("aut"),comment=c(ORCID="0000-0002-8363-656X")),
             person("Klaus", "Hammel", , ,role = c("aut")),
             person("Martin", "Kennel", , ,role = c("aut")),
             person("Anthony", "Federer", , , role = c("aut")),
             person("Tobias", "Hohenbrink", role=c("aut"), comment=c(ORCID="0000-0002-5227-0171")),
             person("Gisbert", "Hetkamp", role=c("aut")),
             person("Michael", "Köhler", role=c("aut"),comment=c(ORCID="0000-0002-7593-5471")),
             person("Robert", "Nuske", role=c("ctb"), comment=c(ORCID="0000-0001-9773-2061")),
             person("Bavarian State Institute of Forestry (LWF)", , role=c("cph", "fnd")),
             person("Northwest German Forest Research Institute (NW-FVA)", , role=c("cph", "fnd")))
Description: Provides a flexible and easy-to use interface for the soil vegetation 
    atmosphere transport (SVAT) model LWF-BROOK90, written in Fortran.
    The model simulates daily transpiration, interception, soil and snow evaporation, 
    streamflow and soil water fluxes through a soil profile covered with vegetation, 
    as described in Hammel & Kennel (2001, ISBN:978-3-933506-16-0) and Federer et al. (2003) 
    <doi:10.1175/1525-7541(2003)004%3C1276:SOAETS%3E2.0.CO;2>. A set of high-level functions
    for model set up, execution and parallelization provides easy access to plot-level SVAT 
    simulations, as well as multi-run and large-scale applications. 
License: GPL-3
Encoding: UTF-8
URL: https://pschmidtwalter.github.io/LWFBrook90R/,
        https://github.com/pschmidtwalter/LWFBrook90R
BugReports: https://github.com/pschmidtwalter/LWFBrook90R/issues
NeedsCompilation: yes
Depends: R (>= 3.4.0)
Imports: methods, data.table (>= 1.10.4), vegperiod (>= 0.3.0), foreach
        (>= 1.5.0), iterators (>= 1.0.12), doFuture (>= 0.10.0), future
        (>= 1.19.0), parallelly (>= 1.30.0), progressr (>= 0.6.0)
Suggests: knitr, rmarkdown, roxygen2, testthat
LazyData: true
RoxygenNote: 7.3.3
VignetteBuilder: knitr
Packaged: 2025-11-18 07:59:04 UTC; pschmidt
Author: Paul Schmidt-Walter [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-2699-0893>),
  Volodymyr Trotsiuk [aut] (ORCID:
    <https://orcid.org/0000-0002-8363-656X>),
  Klaus Hammel [aut],
  Martin Kennel [aut],
  Anthony Federer [aut],
  Tobias Hohenbrink [aut] (ORCID:
    <https://orcid.org/0000-0002-5227-0171>),
  Gisbert Hetkamp [aut],
  Michael Köhler [aut] (ORCID: <https://orcid.org/0000-0002-7593-5471>),
  Robert Nuske [ctb] (ORCID: <https://orcid.org/0000-0001-9773-2061>),
  Bavarian State Institute of Forestry (LWF) [cph, fnd],
  Northwest German Forest Research Institute (NW-FVA) [cph, fnd]
Maintainer: Paul Schmidt-Walter <paulsw@posteo.de>
Repository: CRAN
Date/Publication: 2025-11-18 08:30:17 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-28 06:12:21 UTC; unix
Archs: LWFBrook90R.so.dSYM
