# Generated by roxygen2: do not edit by hand

export(approx_standprop)
export(calc_globrad)
export(calc_vegperiod)
export(correct_prec)
export(extract_layer_output)
export(hydpar_ff_b90)
export(hydpar_hypres)
export(hydpar_hypres_tab)
export(hydpar_puh2)
export(hydpar_wessolek_tab)
export(make_rootden)
export(make_seasLAI)
export(make_standprop)
export(param_to_rlwfbrook90)
export(plant_b90)
export(plant_coupmodel)
export(plant_linear)
export(process_outputs_LWFB90)
export(r_lwfbrook90)
export(replace_vecelements)
export(run_LWFB90)
export(run_multi_LWFB90)
export(run_multisite_LWFB90)
export(set_optionsLWFB90)
export(set_outputLWFB90)
export(set_paramLWFB90)
export(siteparam_to_rlwfbrook90)
export(soil_to_param)
export(standprop_yearly_to_param)
import(data.table)
useDynLib(LWFBrook90R)
